import Vue from 'vue'
import Router from 'vue-router'

import { message } from 'element-ui'

Vue.use(Router)

// 解决ElementUi导航栏中的vue-router在3.0版本以上重复点菜单报错问题
const originalPush = Router.prototype.push

Router.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
}

const router = new Router({
  routes: [
    {
      path: '/',
      name: 'home',
      component: () => import('../views/home.vue'),
      title: '一键发单',
      icon: '/static/image/order-icon.png',
      children: [
        {
          path: '/',
          name: 'HomeIndex',
          title: '订单列表',
          component: () => import('../components/Home.vue')
        },
        {
          path: '/orderSearch',
          name: 'orderSearch',
          title: '订单查询',
          component: () => import('../components/orderSearch.vue')
        },
        {
          path: '/setUp/set',
          name: 'set',
          title: '订单',
          component: () => import('../components/set.vue')
        },
        {
          path: '/shopInfo/shopInfos',
          name: 'shopInfos',
          title: '门店管理',
          component: () => import('../components/shopInfo.vue')
        }
      ]
    },
    {
      path: '/login',
      name: 'login',
      component: () => import('../views/login.vue'),
      title: '登录',
      authority: false
    },
    {
      path: '/resetPassword',
      name: 'resetPassword',
      component: () => import('../views/resetPassword.vue'),
      title: '重置密码',
      authority: false
    }
  ]
})

router.beforeEach((to, from, next) => {
  console.log(to)
  if ( to.path === '/login' ) {
    next()
  }else {
    const token = localStorage.getItem('token') || null;
    if ( token ) {
      next()
    }else if ( to.path !== '/resetPassword' ){
      message({
        message: '请先登录',
        type: 'error',
        duration: 1.5 * 1000
      })
      router.push('/login')
    }else {
      next()
    }
  }
})

export default router
